@@ -27,3 +27,10 @@ import tensorflow as tf
 from tensorflow.python.keras.engine.keras_tensor import KerasTensor
 
 AnyTensor = Union[tf.Tensor, KerasTensor]
+
+try:
+    # tf 2.5.x
+    from tensorflow.python.keras.utils.tf_utils import sync_to_numpy_or_python_type
+except ImportError:
+    # tf 2.4.x
+    from tensorflow.python.keras.utils.tf_utils import to_numpy_or_python_type as sync_to_numpy_or_python_type
